@@ -18,21 +18,19 @@
 
 
 #include "localvideosmodel.h"
+#include "../localthumbnailprovider.h"
 
-#include <libs/mediacenter/mediacenter.h>
-#include <libs/mediacenter/abstractbrowsingbackend.h>
+#include <mediacenter/mediacenter.h>
+#include <mediacenter/abstractbrowsingbackend.h>
 
 #include <KDirModel>
 
 #include <QtDeclarative/QDeclarativeEngine>
 
-LocalVideosModel::LocalVideosModel (QObject* parent)
+LocalVideosModel::LocalVideosModel (ThumbnailProvider *thumbnailProvider, QObject* parent)
     : LocalFilesAbstractModel (parent, QString("video/")),
-    m_thumbProvider(new ThumbnailProvider(this))
+    m_thumbProvider(thumbnailProvider)
 {
-    MediaCenter::AbstractBrowsingBackend *backend = qobject_cast<MediaCenter::AbstractBrowsingBackend*>(parent);
-    backend->declarativeEngine()->addImageProvider("localvideothumbnail", m_thumbProvider);
-
     connect(m_thumbProvider, SIGNAL(gotThumbnail(QString)), SLOT(processThumbnail(QString)));
 }
 
