@@ -22,8 +22,7 @@
 
 #include "../localfilesabstractmodel.h"
 
-#include "../localthumbnailprovider.h"
-
+class ThumbnailProvider;
 /**
   * @class LocalVideosModel @author Shantanu Tushar 
   * @brief Model for Local Videos
@@ -45,8 +44,8 @@ public:
      * 
      * @param parent is a QObject pointer
      */
-    explicit LocalVideosModel (QObject* parent);
-    
+    explicit LocalVideosModel (ThumbnailProvider *thumbnailProvider, QObject* parent);
+
      /**
      * Returns the data stored under the given role for the item referred to by the index.
      * Also thumbnail loading for the folders is here
