@@ -22,17 +22,13 @@
 
 #include "metadatamusicbackend.h"
 #include "alwaysexpandedmetadatamodel.h"
+#include "metadatamusicsongsmodel.h"
 #include "../metadatabackendcommonmodel.h"
 
-#include <libs/mediacenter/pmcmetadatamodel.h>
-#include <libs/mediacenter/playlistmodel.h>
-
-#include <Nepomuk2/Vocabulary/NMM>
-#include <Nepomuk2/Vocabulary/NFO>
-#include <Nepomuk2/Query/AndTerm>
-#include <Nepomuk2/Query/ComparisonTerm>
-#include <Nepomuk2/Query/ResourceTypeTerm>
-#include <Nepomuk2/Query/ResourceTerm>
+#include <mediacenter/pmcmetadatamodel.h>
+#include <mediacenter/playlistmodel.h>
+#include <mediacenter/filtermediamodel.h>
+#include <mediacenter/pmcruntime.h>
 
 #include <KDebug>
 
@@ -52,8 +48,6 @@ MetadataMusicBackend::MetadataMusicBackend(QObject* parent, const QVariantList&
     , m_artistsModel(0)
     , m_albumsModel(0)
     , m_musicModel(0)
-    , m_playlistModel(0)
-    , m_shallAddMediaToPlaylist(false)
 {
 }
 
@@ -66,14 +60,22 @@ bool MetadataMusicBackend::initImpl()
     AbstractMetadataBackend::initImpl();
     m_albumsModel = new AlwaysExpandedMetadataModel(this);
     m_artistsModel = new AlwaysExpandedMetadataModel(this);
-    m_musicModel = new MetadataBackendCommonModel(this);
+    m_musicModel = new MetadataMusicSongsModel(this);
     m_artistsModel->setDefaultDecoration("user-identity");
     m_albumsModel->setDefaultDecoration("pmcnocover");
     connect(m_musicModel, SIGNAL(modelReset()), SLOT(musicModelReset()));
 
-    m_musicModelMetadata = new ModelMetadata(m_musicModel, this);
-    m_albumsModelMetadata = new ModelMetadata(m_albumsModel, this);
-    m_artistsModelMetadata = new ModelMetadata(m_artistsModel, this);
+    m_musicFilteredModel = new FilterMediaModel(this);
+    m_musicFilteredModel->setSourceModel(m_musicModel);
+    m_musicModelMetadata = new ModelMetadata(m_musicFilteredModel, this);
+
+    m_albumFilteredModel = new FilterMediaModel(this);
+    m_albumFilteredModel->setSourceModel(m_albumsModel);
+    m_albumsModelMetadata = new ModelMetadata(m_albumFilteredModel, this);
+
+    m_artistFilteredModel = new FilterMediaModel(this);
+    m_artistFilteredModel->setSourceModel(m_artistsModel);
+    m_artistsModelMetadata = new ModelMetadata(m_artistFilteredModel, this);
 
     m_albumsModelMetadata->setName("Albums");
     m_artistsModelMetadata->setName("Artists");
@@ -93,8 +95,8 @@ bool MetadataMusicBackend::initImpl()
 
 void MetadataMusicBackend::initializeModels()
 {
-    m_albumsModel->showMediaForProperty(Nepomuk2::Vocabulary::NMM::musicAlbum());
-    m_artistsModel->showMediaForProperty(Nepomuk2::Vocabulary::NMM::performer());
+    m_albumsModel->showAlbums();
+    m_artistsModel->showArtist();
     m_musicModel->showMediaType(MediaCenter::Music);
     updateModelAccordingToFilters();
 }
@@ -127,94 +129,41 @@ void MetadataMusicBackend::setArtistFilter(const QString& filter)
     updateModelAccordingToFilters();
 }
 
-void MetadataMusicBackend::clearFilters()
-{
-    m_musicModelMetadata->setHeaderText(QString());
-    m_musicModel->clearAllFilters();
-}
-
 void MetadataMusicBackend::updateModelAccordingToFilters()
 {
-    clearFilters();
+    FilterMediaModel *filterModel = static_cast<FilterMediaModel *> (m_musicFilteredModel);
+    filterModel->clearFilters();
 
     if (!m_albumFilter.isEmpty()) {
-        Nepomuk2::Resource r(m_albumFilter);
-        m_musicModelMetadata->setHeaderText(QString("Showing music from %1, click %2 to reset").arg(r.genericLabel()).arg(s_showAllButton));
-        m_musicModel->addFilter(Nepomuk2::Vocabulary::NMM::musicAlbum(), Nepomuk2::Query::ResourceTerm(m_albumFilter));
+        filterModel->setFilter(MediaCenter::AlbumRole, m_albumFilter);
     }
     if (!m_artistFilter.isEmpty()) {
-        Nepomuk2::Resource r(m_artistFilter);
-        m_musicModelMetadata->setHeaderText(QString("Showing music from %1, click %2 to reset").arg(r.genericLabel()).arg(s_showAllButton));
-        m_musicModel->addFilter(Nepomuk2::Vocabulary::NMM::performer(), Nepomuk2::Query::ResourceTerm(m_artistFilter));
+        filterModel->setFilter(MediaCenter::ArtistRole, m_artistFilter);
     }
 }
 
-void MetadataMusicBackend::searchAlbum(const QString& album)
+void MetadataMusicBackend::addAllSongsToPlaylist (const QSharedPointer<PlaylistModel> &playlistModel)
 {
-    m_albumsModel->setSearchTerm(album);
-}
-
-void MetadataMusicBackend::searchArtist(const QString& artist)
-{
-    m_artistsModel->setSearchTerm(artist);
-}
-
-void MetadataMusicBackend::searchMusic(const QString& music)
-{
-    m_musicModel->setSearchTerm(music);
-}
-
-void MetadataMusicBackend::addAllSongsToPlaylist (QObject* playlistModel)
-{
-    m_shallAddMediaToPlaylist = true;
-    m_playlistModel = qobject_cast<PlaylistModel*>(playlistModel);
-    if (!m_playlistModel)
-        return;
-    for (int i=0; i<m_musicModel->rowCount(); ++i) {
-        const QString url = m_musicModel->data(m_musicModel->index(i), MediaCenter::MediaUrlRole).toString();
-        const QString name = m_musicModel->data(m_musicModel->index(i), Qt::DisplayRole).toString();
+    for (int i=0; i<m_musicFilteredModel->rowCount(); ++i) {
+        const QString url = m_musicFilteredModel->data(m_musicFilteredModel->index(i, 0), MediaCenter::MediaUrlRole).toString();
+        const QVariantList songAndItsInfo = m_musicFilteredModel->data(m_musicFilteredModel->index(i, 0), Qt::DisplayRole).toList();
+        const QString name = songAndItsInfo.length() ? songAndItsInfo.at(0).toString() : QString();
         if (!url.isEmpty() && !name.isEmpty()) {
-            m_playlistModel->addToPlaylist(url);
+            playlistModel->addToPlaylist(url);
         }
     }
-
-    disconnect(m_musicModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(musicModelDataChanged(QModelIndex,QModelIndex)));
-    connect(m_musicModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(musicModelDataChanged(QModelIndex,QModelIndex)));
-}
-
-void MetadataMusicBackend::musicModelDataChanged ( const QModelIndex &startIndex, const QModelIndex &endIndex )
-{
-    if ( !(startIndex.isValid() && endIndex.isValid() && m_shallAddMediaToPlaylist ))
-        return;
-    for (int i=startIndex.row(); i<=endIndex.row(); ++i) {
-        const QString url = m_musicModel->data(m_musicModel->index(i), MediaCenter::MediaUrlRole).toString();
-        const QString name = m_musicModel->data(m_musicModel->index(i), Qt::DisplayRole).toString();
-        if (!url.isEmpty() && !name.isEmpty()) {
-            m_playlistModel->addToPlaylist(url);
-        }
-    }
-}
-
-void MetadataMusicBackend::musicModelReset()
-{
-    disconnect(m_musicModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(musicModelDataChanged(QModelIndex,QModelIndex)));
-}
-
-void MetadataMusicBackend::stopAddingSongsToPlaylist()
-{
-    m_shallAddMediaToPlaylist = false;
 }
 
 bool MetadataMusicBackend::expand(int row, QAbstractItemModel* model)
 {
     if (!model) return false;
 
-    const QString filter = model->data(model->index(row, 0), MediaCenter::ResourceIdRole).toString();
+    const QString filter = model->data(model->index(row, 0), Qt::DisplayRole).toString();
 
-    if (model == m_albumsModel) {
+    if (model == m_albumFilteredModel) {
         setAlbumFilter(filter);
         emit modelNeedsAttention(m_musicModelMetadata);
-    } else if (model == m_artistsModel) {
+    } else if (model == m_artistFilteredModel) {
         setArtistFilter(filter);
         emit modelNeedsAttention(m_musicModelMetadata);
     }
@@ -235,8 +184,8 @@ void MetadataMusicBackend::handleButtonClick(const QString& buttonName)
         m_albumFilter = m_artistFilter = "";
         updateModelAccordingToFilters();
     } else if (buttonName == s_playAllButton) {
-        //FIXME: This is a horrible hack to get a ref to the playlist model
-        PlaylistModel *model = qobject_cast<PlaylistModel*>(declarativeEngine()->rootContext()->contextProperty("playlistModel").value<QObject*>());
+        auto model = pmcRuntime()->runtimeObjectAs<PlaylistModel>(PmcRuntime::PlaylistModel);
+
         if (model) {
             addAllSongsToPlaylist(model);
             if (pmcRuntime()) {
@@ -251,13 +200,7 @@ void MetadataMusicBackend::handleButtonClick(const QString& buttonName)
 
 void MetadataMusicBackend::searchModel(const QString& searchTerm, QAbstractItemModel* model)
 {
-    if (model == m_musicModel) {
-        searchMusic(searchTerm);
-    } else if (model == m_artistsModel) {
-        searchArtist(searchTerm);
-    } else if (model == m_albumsModel) {
-        searchAlbum(searchTerm);
-    }
+    static_cast<FilterMediaModel *> (model)->setFilter(Qt::DisplayRole, searchTerm);
 }
 
 #include "metadatamusicbackend.moc"
