@@ -21,11 +21,10 @@
 #ifndef METADATAMUSICBACKEND_H
 #define METADATAMUSICBACKEND_H
 
-#include <libs/mediacenter/abstractbrowsingbackend.h>
-
 #include "../abstractmetadatabackend.h"
 #include "categoriesmodel.h"
 
+class FilterMediaModel;
 class MetadataBackendCommonModel;
 class AlwaysExpandedMetadataModel;
 class PlaylistModel;
@@ -50,12 +49,7 @@ public:
     void setArtistFilter(const QString &filter);
     void setAlbumFilter(const QString &filter);
 
-    Q_INVOKABLE void searchArtist(const QString &artist);
-    Q_INVOKABLE void searchAlbum(const QString &album);
-    Q_INVOKABLE void searchMusic(const QString &music);
-
-    Q_INVOKABLE void addAllSongsToPlaylist( QObject* playlistModel );
-    Q_INVOKABLE void stopAddingSongsToPlaylist();
+    void addAllSongsToPlaylist( const QSharedPointer< PlaylistModel >& playlistModel );
 
     virtual bool expand(int row, QAbstractItemModel* model);
 
@@ -70,12 +64,10 @@ Q_SIGNALS:
 
 protected:
     void updateModelAccordingToFilters();
-    void clearFilters();
     virtual bool initImpl();
 
 private slots:
-    void musicModelDataChanged ( const QModelIndex& startIndex, const QModelIndex& endIndex );
-    void musicModelReset();
+
     void initializeModels();
 
 private:
@@ -86,10 +78,12 @@ private:
 
     QString m_artistFilter;
     QString m_albumFilter;
-    bool m_shallAddMediaToPlaylist : 1;
     ModelMetadata* m_musicModelMetadata;
     ModelMetadata* m_albumsModelMetadata;
     ModelMetadata* m_artistsModelMetadata;
+    FilterMediaModel* m_musicFilteredModel;
+    FilterMediaModel* m_albumFilteredModel;
+    FilterMediaModel* m_artistFilteredModel;
 };
 
 #endif // METADATAMUSICBACKEND_H
