@@ -23,7 +23,7 @@
 #include "metadatavideobackend.h"
 #include "metadatavideomodel.h"
 
-#include <Nepomuk2/Query/QueryParser>
+#include <mediacenter/filtermediamodel.h>
 
 #include <QDebug>
 
@@ -42,7 +42,13 @@ bool MetadataVideoBackend::initImpl()
 {
     AbstractMetadataBackend::initImpl();
     MetadataVideoModel *model = new MetadataVideoModel(this);
-    ModelMetadata *metadata = new ModelMetadata(model, this);
+
+    FilterMediaModel *filteredModel = new FilterMediaModel(this);
+    filteredModel->setSourceModel(model);
+    filteredModel->setSortRole(MediaCenter::CreatedAtRole);
+    filteredModel->sort(0, Qt::DescendingOrder);
+    ModelMetadata *metadata = new ModelMetadata(filteredModel, this);
+
     metadata->setSupportsSearch(true);
     handleBusySignals(model);
     setModel(metadata);
@@ -51,7 +57,9 @@ bool MetadataVideoBackend::initImpl()
 
 void MetadataVideoBackend::search(const QString& searchTerm)
 {
-    qobject_cast<PmcMetadataModel*>(model())->setSearchTerm(QString(searchTerm).prepend("*").append("*"));
+    if (model()) {
+        static_cast<FilterMediaModel *> (model())->setFilter(Qt::DisplayRole, searchTerm);
+    }
 }
 
 #include "metadatavideobackend.moc"
