@@ -17,7 +17,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
  ***************************************************************************/
 #include "youtubemodel.h"
-#include <libs/mediacenter/mediacenter.h>
+#include <mediacenter/mediacenter.h>
 // Qt
 #include <QDomDocument>
 #include <QDomNodeList>
@@ -25,6 +25,7 @@
 #include <kio/job.h>
 #include <KUrl>
 #include <QDebug>
+#include <QDate>
 
 
 YoutubeModel::YoutubeModel(QObject* parent): QAbstractListModel(parent)
@@ -33,11 +34,6 @@ YoutubeModel::YoutubeModel(QObject* parent): QAbstractListModel(parent)
     setRoleNames(MediaCenter::appendAdditionalMediaRoles(roleNames()));
 }
 
-YoutubeModel::~YoutubeModel()
-{
-
-}
-
 QVariant YoutubeModel::data(const QModelIndex& index, int role) const
 {
     switch (role) {
@@ -53,12 +49,15 @@ QVariant YoutubeModel::data(const QModelIndex& index, int role) const
             return "video";
         case MediaCenter::IsExpandableRole:
             return true;
+	case MediaCenter::DurationRole:
+	    return m_videos.at(index.row()).duration;
     }
     return QVariant();
 }
 
 int YoutubeModel::rowCount(const QModelIndex& parent) const
 {
+    Q_UNUSED(parent);
     return m_videos.count();
 }
 
@@ -79,8 +78,8 @@ void YoutubeModel::query(const QString &searchTerm)
 
     KIO::TransferJob *job = KIO::get(query, KIO::NoReload, KIO::HideProgressInfo);
     m_queries[job] = searchTerm;
-    connect (job, SIGNAL(data(KIO::Job*, const QByteArray &)), this, SLOT(ytDataReady(KIO::Job*, const QByteArray &)));
-    connect (job, SIGNAL(result(KJob *)), this, SLOT(parseResults(KJob*)));
+    connect (job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(ytDataReady(KIO::Job*,QByteArray)));
+    connect (job, SIGNAL(result(KJob*)), this, SLOT(parseResults(KJob*)));
 }
 
 void YoutubeModel::ytDataReady(KIO::Job *job, const QByteArray &data)
@@ -104,12 +103,13 @@ void YoutubeModel::parseResults(KJob *job)
 
     QDomNodeList entries = document.elementsByTagName("entry");
     for (int i = 0; i < entries.count(); i++) {
-        QString id = entries.at(i).namedItem("id").toElement().text().split(":").last();
+        QString id = entries.at(i).namedItem("id").toElement().text().split(':').last();
         QString title = entries.at(i).namedItem("title").toElement().text();
         QDomNode mediaNode = entries.at(i).namedItem("media:group");
         QString description = mediaNode.namedItem("media:description").toElement().text();
         QString keywords = mediaNode.namedItem("media:keywords").toElement().text();
         QString mediaUrl = mediaNode.namedItem("media:player").toElement().attribute("url");
+	uint mediaDuration = mediaNode.namedItem("yt:duration").toElement().attribute("seconds").toInt();
         // FIXME: more than one media:thumbnail exists
         QString thumbnail = mediaNode.namedItem("media:thumbnail").toElement().attribute("url");
 
@@ -138,7 +138,7 @@ void YoutubeModel::parseResults(KJob *job)
         video.description = description;
         video.keywords = keywords.split(", ");
         video.id = id;
-        video.duration = 0;
+        video.duration = mediaDuration;
         video.embeddedHTML = embeddedHTML;
         video.thumbnail = thumbnail;
         video.url = mediaUrl;
