@@ -37,7 +37,7 @@ public:
     AbstractBrowsingBackendPrivate(AbstractBrowsingBackend *q) :
     q(q),
     cfInterface(false),
-    declarativeEngine(0),
+    declarativeEngine(nullptr),
     hasInitialized(false)
     {}
 
@@ -49,7 +49,7 @@ public:
     QString mediaBrowserSidePanelText;
     QList<QObject*> models;
     QString searchTerm;
-    QObject* pmcRuntime;
+    QSharedPointer<PmcRuntime> pmcRuntime;
 };
 
 AbstractBrowsingBackend::AbstractBrowsingBackend(QObject *parent, const QVariantList &args)
@@ -141,16 +141,6 @@ bool AbstractBrowsingBackend::expand(int row)
     return false;
 }
 
-QDeclarativeEngine *AbstractBrowsingBackend::declarativeEngine() const
-{
-    return d->declarativeEngine;
-}
-
-void AbstractBrowsingBackend::setDeclarativeEngine(QDeclarativeEngine *declarativeEngine)
-{
-    d->declarativeEngine = declarativeEngine;
-}
-
 QString AbstractBrowsingBackend::constructQmlSource(const QString& componentDirName, const QString &versionString,
                                                     const QString& itemName) const
 {
@@ -168,13 +158,6 @@ QString AbstractBrowsingBackend::mediaBrowserSidePanel() const
     return d->mediaBrowserSidePanelText;
 }
 
-void AbstractBrowsingBackend::setMediaBrowserSidePanel(QString text)
-{
-    d->mediaBrowserSidePanelText = text;
-    emit mediaBrowserSidePanelChanged();
-}
-
-
 bool AbstractBrowsingBackend::okToLoad() const
 {
     return true;
@@ -219,19 +202,16 @@ QVariantList AbstractBrowsingBackend::buttons()
     return QVariantList();
 }
 
-void AbstractBrowsingBackend::handleButtonClick(const QString& buttonName)
+void AbstractBrowsingBackend::handleButtonClick(const QString&)
 {
 }
 
-QObject* AbstractBrowsingBackend::pmcRuntime()
+void AbstractBrowsingBackend::setPmcRuntime(const QSharedPointer<PmcRuntime> &pmcRuntime)
+{
+    d->pmcRuntime = pmcRuntime;
+}
+
+QSharedPointer<PmcRuntime> AbstractBrowsingBackend::pmcRuntime() const
 {
     return d->pmcRuntime;
 }
-
-void AbstractBrowsingBackend::setPmcRuntime(QObject* pmcRuntime)
-{
-    if (d->pmcRuntime != pmcRuntime) {
-        d->pmcRuntime = pmcRuntime;
-        emit pmcRuntimeChanged();
-    }
-}
