@@ -20,19 +20,18 @@
 #define ABSTRACTBROWSINGBACKEND_H
 
 #include <QObject>
-#include <QVariantList>
-#include <QFlags>
 
 #include <KDE/KConfigGroup>
 #include <KDE/KService>
 
 #include "mediacenter_export.h"
-#include "mediacenter/mediacenter.h"
+#include "mediacenter.h"
 
-class QDeclarativeEngine;
+class QDeclarativeImageProvider;
 class QAbstractItemModel;
 class KConfigDialog;
 class ModelMetadata;
+class PmcRuntime;
 
 namespace MediaCenter {
 
@@ -52,10 +51,9 @@ class MEDIACENTER_EXPORT AbstractBrowsingBackend : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool busy READ busy NOTIFY busyChanged)
-    Q_PROPERTY(QString mediaBrowserSidePanel READ mediaBrowserSidePanel WRITE setMediaBrowserSidePanel NOTIFY mediaBrowserSidePanelChanged)
+    Q_PROPERTY(QString mediaBrowserSidePanel READ mediaBrowserSidePanel NOTIFY mediaBrowserSidePanelChanged)
     Q_PROPERTY(QVariantList models READ models NOTIFY modelsChanged)
     Q_PROPERTY(QVariantList buttons READ buttons NOTIFY buttonsChanged)
-    Q_PROPERTY(QObject* pmcRuntime READ pmcRuntime WRITE setPmcRuntime NOTIFY pmcRuntimeChanged)
 
 public:
     /**
@@ -145,22 +143,6 @@ public:
      */
     Q_INVOKABLE virtual bool expand(int row);
 
-    /**
-     * This slot must be called by the MediaCenter UI to set a declarive engine
-     * which can then be used by the backend to set up needed values at runtime
-     *
-     * @param declarativeEngine pointer to the declarative engine
-     */
-    void setDeclarativeEngine(QDeclarativeEngine *declarativeEngine);
-
-    /**
-     * Use this method to get access to the declarative engine.
-     * This is useful for backends to provide their own image providers and so on
-     *
-     * @return the declarative engine
-     */
-    QDeclarativeEngine *declarativeEngine() const;
-
     /**
      * Override this method if you want your backend to show a custom media browser
      * instead of the standard PMC MediaBrowser.
@@ -178,7 +160,6 @@ public:
      */
     virtual bool okToLoad() const;
 
-    //TODO: Side panel concept is hacky, replace with a popup of some sort
     /**
      * Override this method if you want your backend to show custom items on a
      * panel/popup. For example this can be used to set filtering options
@@ -187,8 +168,6 @@ public:
      */
      virtual QString mediaBrowserSidePanel() const;
 
-     virtual void setMediaBrowserSidePanel(QString text);
-
     /**
      * Override this method and emit the busyChanged() signal to tell the mediacenter
      * that the backend is busy doing something
@@ -203,11 +182,12 @@ public:
      *
      * @param buttonName the name of the button that was clicked
      */
-    Q_INVOKABLE virtual void handleButtonClick(const QString &buttonName);
+    Q_INVOKABLE virtual void handleButtonClick(const QString&);
 
-    //FIXME: Bad, bad, bad.
-    QObject* pmcRuntime();
-    void setPmcRuntime(QObject* pmcRuntime);
+    /**
+     * @internal
+     */
+    void setPmcRuntime(const QSharedPointer<PmcRuntime> &pmcRuntime);
 
 Q_SIGNALS:
     void busyChanged();
@@ -284,10 +264,17 @@ protected:
      */
     Q_INVOKABLE virtual void searchModel(const QString &searchTerm, QAbstractItemModel *model);
 
+    /**
+     * Subclasses can call this method to access the PmcRuntime which can be
+     * then used to access PMC runtime objects.
+     *
+     * @return QSharedPointer to the PmcRuntime object
+     */
+    QSharedPointer< PmcRuntime > pmcRuntime() const;
+
 private:
     class AbstractBrowsingBackendPrivate;
     AbstractBrowsingBackendPrivate * const d;
-
 };
 
 } // MediaCenter namespace
