@@ -22,7 +22,7 @@
 
 #include <KDebug>
 
-#include <libs/mediacenter/abstractbrowsingbackend.h>
+#include "abstractbrowsingbackend.h"
 
 bool pluginLessThan(const KPluginInfo &lh, const KPluginInfo &rh)
 {
@@ -32,17 +32,17 @@ bool pluginLessThan(const KPluginInfo &lh, const KPluginInfo &rh)
 class BackendsModel::Private
 {
 public:
-    QWeakPointer<QDeclarativeEngine> declarativeEngine;
     QHash<QString, MediaCenter::AbstractBrowsingBackend*> backends;
     KPluginInfo::List backendInfo;
     KPluginInfo::List loadedBackendsInfo;
+    QWeakPointer<PmcRuntime> pmcRuntime;
 };
 
-BackendsModel::BackendsModel(QDeclarativeEngine *engine, QObject* parent)
+BackendsModel::BackendsModel(QWeakPointer<PmcRuntime> pmcRuntime, QObject* parent)
     : QAbstractListModel(parent)
     , d(new Private)
 {
-    d->declarativeEngine = engine;
+    d->pmcRuntime = pmcRuntime;
     KService::List services = MediaCenter::AbstractBrowsingBackend::availableBackends();
     d->backendInfo = KPluginInfo::fromServices(services);
     qStableSort(d->backendInfo.begin(), d->backendInfo.end(), pluginLessThan);
@@ -69,7 +69,11 @@ void BackendsModel::loadBrowsingBackends()
 
         const QString key = service->library();
         QString errorMessage;
-        MediaCenter::AbstractBrowsingBackend *backend = service->createInstance<MediaCenter::AbstractBrowsingBackend>(0, QVariantList() << service->storageId(), &errorMessage);
+
+        MediaCenter::AbstractBrowsingBackend *backend =
+            service->createInstance<MediaCenter::AbstractBrowsingBackend>(
+                0, QVariantList() << service->storageId(), &errorMessage);
+
         if (backend) {
             if (!backend->okToLoad()) {
                 kDebug() << "Backend " << info.name() << " doesn't want to be loaded";
@@ -77,9 +81,7 @@ void BackendsModel::loadBrowsingBackends()
             }
             backend->setName(info.pluginName());
             backend->setParent(const_cast<BackendsModel *>(this));
-            if (d->declarativeEngine) {
-                backend->setDeclarativeEngine(d->declarativeEngine.data());
-            }
+            backend->setPmcRuntime(d->pmcRuntime);
             const_cast<BackendsModel *>(this)->d->backends.insert(key, backend);
             d->loadedBackendsInfo.append(info);
         } else {
@@ -118,5 +120,3 @@ int BackendsModel::rowCount(const QModelIndex &) const
 {
     return d->loadedBackendsInfo.count();
 }
-
-#include "backendsmodel.moc"
