@@ -18,10 +18,13 @@
 
 #include "mediacenter.h"
 
+#include <QDir>
 #include <QFileInfo>
 
 #include <KMimeType>
 #include <KUrl>
+#include <KCmdLineArgs>
+#include <KStandardDirs>
 
 #include <Solid/Device>
 #include <Solid/OpticalDisc>
@@ -39,8 +42,20 @@ QHash<int, QByteArray> appendAdditionalMediaRoles (const QHash<int, QByteArray>
     newRoles[DecorationTypeRole] = "decorationType";
     newRoles[HideLabelRole] = "hideLabel";
     newRoles[ResourceIdRole] = "resourceId";
-    newRoles[MediaThumbnailRole] = "mediaThumbnail";
+    newRoles[DurationRole] = "mediaDuration";
+    newRoles[ArtistRole] = "mediaArtist";
+    newRoles[AlbumRole] = "mediaAlbum";
+    newRoles[GenreRole] = "mediaGenre";
     return newRoles;
 }
 
+QString dataDirForComponent(const QString& component)
+{
+  static const QString pmcPath = KGlobal::dirs()->saveLocation("data") + KCmdLineArgs::appName();
+  if(!QDir(pmcPath).exists()) {
+    QDir().mkpath(pmcPath);
+  }
+  return pmcPath + (component.isEmpty() ? QString() : QString("/%1").arg(component));
+}
+
 } // MediaCenter namespace
