@@ -17,6 +17,7 @@
 
 #include "playlistmodel.h"
 #include "playlistitem.h"
+#include "settings.h"
 
 #include <KDebug>
 #include <KDE/KStandardDirs>
@@ -32,6 +33,7 @@
 
 namespace {
     static const char DEFAULT_PLAYLIST_NAME[] = "Default";
+    static int INVALID_INDEX = -1;
 }
 
 class PlaylistModel::Private
@@ -50,10 +52,11 @@ PlaylistModel::PlaylistModel(QObject* parent):
     QAbstractListModel(parent),
     d(new Private)
 {
-    d->playlistName = DEFAULT_PLAYLIST_NAME;
+    Settings s;
+    d->playlistName = s.value("lastPlaylist", DEFAULT_PLAYLIST_NAME).toString();
     loadFromFile(playlistFilePath());
 
-    d->currentIndex = -1;
+    resetCurrentIndex();
     setRoleNames(MediaCenter::appendAdditionalMediaRoles(roleNames()));
 
     QHash<int, QByteArray> newRoles(roleNames());
@@ -71,6 +74,9 @@ PlaylistModel::PlaylistModel(QObject* parent):
 
 PlaylistModel::~PlaylistModel()
 {
+    Settings s;
+    s.setValue("lastPlaylist", d->playlistName);
+    s.sync();
     savePlaylist();
 }
 
@@ -126,33 +132,37 @@ void PlaylistModel::addToPlaylist(const QString& url)
 
 void PlaylistModel::removeFromPlaylist(const int& index)
 {
-    beginResetModel();
+    beginRemoveRows(QModelIndex(), index, index);
     d->musicList.takeAt(index)->deleteLater();
     if (index <= d->currentIndex) {
         d->currentIndex -= 1;
     }
-    endResetModel();
+    endRemoveRows();
 }
 
 void PlaylistModel::moveItem(int originalIndex, int newIndex)
 {
+    int moveBeforeRow = (newIndex > originalIndex) ? newIndex + 1 : newIndex;
+
+    beginMoveRows(QModelIndex(), originalIndex, originalIndex, QModelIndex(), moveBeforeRow);
     d->musicList.move(originalIndex, newIndex);
+    endMoveRows();
+
     if (originalIndex == d->currentIndex) {
         setCurrentIndex(newIndex);
     } else if (originalIndex < d->currentIndex && newIndex >= d->currentIndex) {
-            setCurrentIndex(d->currentIndex-1);
+        setCurrentIndex(d->currentIndex-1);
     } else if (originalIndex > d->currentIndex && newIndex <= d->currentIndex) {
-            setCurrentIndex(d->currentIndex+1);
-    }
-    if (originalIndex < newIndex) {
-       emit dataChanged(createIndex(originalIndex, 0), createIndex(newIndex, 0));
-    } else {
-        emit dataChanged(createIndex(newIndex, 0), createIndex(originalIndex, 0));
+        setCurrentIndex(d->currentIndex+1);
     }
 }
 
 void PlaylistModel::playNext()
 {
+    if (d->currentIndex == INVALID_INDEX) {
+        return;
+    }
+
     if (d->currentIndex == d->musicList.count() - 1) {
         setCurrentIndex(0);
     } else {
@@ -164,6 +174,10 @@ void PlaylistModel::playNext()
 
 void PlaylistModel::playPrevious()
 {
+    if (d->currentIndex == INVALID_INDEX) {
+        return;
+    }
+
     if (d->currentIndex == 0) {
         setCurrentIndex(d->musicList.count() - 1);
     } else {
@@ -192,7 +206,7 @@ void PlaylistModel::clearPlaylistWithoutModelReset()
     }
 
     d->musicList.clear();
-    d->currentIndex = -1;
+    resetCurrentIndex();
 }
 
 int PlaylistModel::currentIndex() const
@@ -212,7 +226,7 @@ void PlaylistModel::shuffle()
         return;
 
     QList<PlaylistItem*> musicListShuffle;
-    if( d->currentIndex == -1 )
+    if( d->currentIndex == INVALID_INDEX )
         d->currentIndex = 0;
     musicListShuffle.append(d->musicList.takeAt(d->currentIndex));
 
@@ -236,7 +250,7 @@ void PlaylistModel::playlistItemUpdated()
 
 QString PlaylistModel::playlistFilePath() const
 {
-    return  getPlaylistPath() + d->playlistName;
+    return QDir(getPlaylistPath()).absoluteFilePath(d->playlistName);
 }
 
 void PlaylistModel::loadFromFile(const QString& path)
@@ -250,7 +264,7 @@ void PlaylistModel::loadFromFile(const QString& path)
 
             QDomNodeList itemList = doc.elementsByTagName("item");
             d->musicList.clear();
-            setCurrentIndex(-1);
+            resetCurrentIndex();
             for (int i=0; i<itemList.count(); i++) {
                 QDomNode node = itemList.at(i);
                 if (node.isNull()) continue;
@@ -290,6 +304,11 @@ void PlaylistModel::savePlaylist()
     saveToFile(playlistFilePath());
 }
 
+void PlaylistModel::resetCurrentIndex()
+{
+    setCurrentIndex(INVALID_INDEX);
+}
+
 bool PlaylistModel::removeCurrentPlaylist(const QString &playlistToSwitchToAfterDeletion)
 {
     if (d->playlistName == DEFAULT_PLAYLIST_NAME) {
