@@ -20,23 +20,19 @@
 #ifndef PMCMETADATAMODEL_H
 #define PMCMETADATAMODEL_H
 
-#include <QtCore/QAbstractItemModel>
-
-#include <Nepomuk2/Query/Result>
-#include <Nepomuk2/Query/Term>
-#include <Nepomuk2/Types/Property>
-#include <Nepomuk2/Resource>
-#include <Nepomuk2/Query/ComparisonTerm>
-
 #include "mediacenter_export.h"
 #include "mediacenter.h"
 
-namespace Nepomuk2 {
-namespace Query {
-class ResourceTypeTerm;
-}
-}
+#include <KUrl>
 
+#include <QtCore/QAbstractItemModel>
+#include <QSharedPointer>
+#include <QList>
+
+class PmcArtist;
+class PmcAlbum;
+class PmcMedia;
+class MediaLibrary;
 class QPixmap;
 class KFileItem;
 
@@ -44,22 +40,17 @@ class MEDIACENTER_EXPORT PmcMetadataModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
-    explicit PmcMetadataModel(QObject* parent = 0);
+    explicit PmcMetadataModel(QObject* parent = 0, MediaLibrary* mediaLibrary = 0);
     virtual ~PmcMetadataModel();
     virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
     virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
 
     void showMediaType(MediaCenter::MediaType mediaType);
-    void showMediaForProperty(Nepomuk2::Types::Property property);
-    void setTerm(const Nepomuk2::Query::Term &term);
-    void addTerm(const Nepomuk2::Query::Term &term);
-    void addFilter(const Nepomuk2::Types::Property& property, const Nepomuk2::Query::Term& term, Nepomuk2::Query::ComparisonTerm::Comparator comparator = Nepomuk2::Query::ComparisonTerm::Contains);
-    void setSearchTerm(const QString &searchTerm);
     void setDefaultDecoration(const QVariant &decoration);
 
 public Q_SLOTS:
-    void clearAllFilters();
-    void saveMetadata(int row, const QHash< int, QVariant >& values);
+    void showAlbums();
+    void showArtist();
 
 signals:
     void queryStarted();
@@ -67,31 +58,36 @@ signals:
     void queryError(const QString &message);
 
 protected Q_SLOTS:
-    void finishedListing();
+    void handleNewMedia(const QList<QSharedPointer<PmcMedia> > &media);
+    void handleNewAlbums(const QList< QSharedPointer< PmcAlbum > > &mediaData);
+    void handleNewArtists(const QList< QSharedPointer< PmcArtist > > &mediaData);
     void updateModel();
     void delayedPreview();
 
 protected:
     QString fetchPreview(const KUrl& url, const QModelIndex& index);
-    QString urlForResource(const Nepomuk2::Resource &resource) const;
-    QString mimetypeForResource(const Nepomuk2::Resource &resource) const;
-    inline QList<int> rolesNeeded() const;
-    void resetModel();
 
 private Q_SLOTS:
-    void newEntries(int count);
     void showPreview(const KFileItem &item, const QPixmap &preview);
     void previewFailed(const KFileItem &item);
     void fetchMetadata();
-    void handleUpdaterReset();
-    void signalUpdate(const QPersistentModelIndex &index, const QString &displayString = QString());
+    void signalUpdate(const QVariant& resourceId, const QString& displayString = QString());
+    void mediaUpdated();
 
 private:
+    enum Mode { Music, Picture, Video, Album, Artist };
+
     class Private;
     Private * const d;
 
-    QVariant decorationForMetadata(const QVariant& metadataValue, const QModelIndex& index) const;
     QVariant metadataValueForRole(const QModelIndex& index, int role) const;
+    QVariant dataForMedia(const QModelIndex& row, int role) const;
+    QVariant dataForArtist(int row, int role) const;
+    QVariant dataForAlbum(int row, int role) const;
+
+    template <class T> void handleNewAlbumsOrArtists(const QList< QSharedPointer< T > > &mediaData);
+    QVariant getAlbumArt(const QString& albumName, const QString& albumArtist, const QString& resourceId) const;
+    QVariant getArtistImage(const QString& artistName, const QString& resourceId) const;
 };
 
 #endif // PMCMETADATAMODEL_H
