@@ -18,23 +18,27 @@
  ***************************************************************************/
 
 #include "mainwindow.h"
-#include "settings.h"
 
-#include <libs/mediacenter/backendsmodel.h>
-#include <libs/mediacenter/playlistmodel.h>
-#include <libs/mediacenter/filterplaylistmodel.h>
-#include <libs/mediacenter/filteredbackendsmodel.h>
-#include <libs/mediacenter/subtitleprovider.h>
-#include <libs/mediacenter/pmcimageprovider.h>
-#include <libs/mediacenter/pmccoverartprovider.h>
-#include <mediacenter/objectpair.h>
+#include <mediacenter/backendsmodel.h>
 #include <mediacenter/filterplaylistmodel.h>
+#include <mediacenter/filteredbackendsmodel.h>
+#include <mediacenter/subtitleprovider.h>
+#include <mediacenter/pmccoverartprovider.h>
+#include <mediacenter/objectpair.h>
+#include <mediacenter/settings.h>
 #include <mediacenter/multipleplaylistmodel.h>
+#include <mediacenter/mpris2/mediaplayer2player.h>
+#include <mediacenter/mpris2/mpris2.h>
+#include <mediacenter/pmcruntime.h>
 
+#ifndef NO_LINK_TO_PLASMA
 #include <Plasma/Package>
 #include <Plasma/Theme>
+#endif
+
 #include <KDE/KCmdLineArgs>
 #include <KDE/KApplication>
+#include <KDE/KWindowSystem>
 
 #include <QtDeclarative/QDeclarativeEngine>
 #include <QtDeclarative/QDeclarativeView>
@@ -42,27 +46,20 @@
 #include <QDeclarativeProperty>
 #include <qdeclarative.h>
 
+#include <QLibrary>
 #include <QtOpenGL/QGLWidget>
 #include <QtGui/QApplication>
 #include <QtGui/QKeyEvent>
 #include <QDebug>
 #include <QTimer>
+#include <QDir>
 
-MainWindow::MainWindow(QWidget *parent)
-    : KMainWindow(parent)
+MainWindow::MainWindow(Application *parent)
+    : KMainWindow(dynamic_cast <QWidget *> (parent))
     , m_mousePointerAutoHide(false)
 {
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-    const int argsCount = args->count();
-
-    QList<KUrl> urls;
-    for (int i = 0; i < argsCount; ++i) {
-        const KUrl url = args->url(i);
-        if (url.isValid()) {
-            urls.append(url);
-        }
-    }
     if (args->isSet("fullscreen") || Settings().value("fullscreen", false).toBool()) {
         toggleFullScreen();
     }
@@ -80,7 +77,6 @@ MainWindow::MainWindow(QWidget *parent)
         view->setViewport(widget);
 #endif
     }
-    args->clear();
 
     view->setAttribute(Qt::WA_OpaquePaintEvent);
     view->setAttribute(Qt::WA_NoSystemBackground);
@@ -101,41 +97,39 @@ MainWindow::MainWindow(QWidget *parent)
     qmlRegisterType<Settings>("org.kde.plasma.mediacenter.elements", 0, 1, "Settings");
     qmlRegisterInterface<ObjectPair>("ObjectPair");
 
-    BackendsModel *backendsModel = new BackendsModel(view->engine(), this);
+    playlistModel = QSharedPointer<PlaylistModel>(new PlaylistModel(this));
+    playlistModel->processCommandLineArgs(args);
+    view->rootContext()->setContextProperty("playlistModel", playlistModel.data());
+
+    BackendsModel *backendsModel = new BackendsModel(createPmcRuntime(view->engine(), playlistModel), this);
     view->rootContext()->setContextProperty("backendsModel", backendsModel);
 
-    PlaylistModel *playlistModel = new PlaylistModel(this);
-    if (urls.length() > 0) {
-        playlistModel->clearPlaylist();
-        foreach (const KUrl &url, urls) {
-            playlistModel->addToPlaylist(url.prettyUrl());
-        }
-    }
-    view->rootContext()->setContextProperty("playlistModel", playlistModel);
+    Mpris2 *mprisObject = new Mpris2(this);
+    connect(mprisObject, SIGNAL(raisePMC()), this, SLOT(raiseAndFocusPMC()));
+
+    MediaPlayer2Player *mp2p = mprisObject->getMediaPlayer2Player();
+    view->rootContext()->setContextProperty("mprisPlayerObject", mp2p);
 
     view->rootContext()->setContextProperty("_pmc_mainwindow", this);
     view->rootContext()->setContextProperty("startedFullScreen", isFullScreen());
 
-    view->engine()->addImageProvider(PmcImageProvider::identificationString, new PmcImageProvider());
     view->engine()->addImageProvider(PmcCoverArtProvider::identificationString, new PmcCoverArtProvider());
 
-    Plasma::Theme::defaultTheme()->setUseGlobalSettings(false);
-    Plasma::Theme::defaultTheme()->setThemeName("oxygen");
+    QString imagesPath;
+    QString mainscriptPath;
 
-    m_structure = Plasma::PackageStructure::load("Plasma/Generic");
-    Plasma::Package *package = new Plasma::Package(QString(), "org.kde.plasma.mediacenter", m_structure);
+    if (!loadThemeAndPopulateMainscriptAndImagesPath(mainscriptPath, imagesPath)) {
+        qFatal("Failed to load Plasma Libraries, cannot continue.");
+    }
 
-    view->rootContext()->setContextProperty("_pmc_background_image_path", QUrl(package->filePath("images", "noiselight.png")));
-    view->rootContext()->setContextProperty("_pmc_gradient_image_path", QUrl(package->filePath("images", "gradient.png")));
-    view->rootContext()->setContextProperty("_pmc_shadow_image_path", QUrl(package->filePath("images", "shadow.png")));
+    view->rootContext()->setContextProperty("_pmc_background_image_path", QUrl(QDir(imagesPath).absoluteFilePath("noiselight.png")));
+    view->rootContext()->setContextProperty("_pmc_gradient_image_path", QUrl(QDir(imagesPath).absoluteFilePath("gradient.png")));
+    view->rootContext()->setContextProperty("_pmc_shadow_image_path", QUrl(QDir(imagesPath).absoluteFilePath("shadow.png")));
 
     view->rootContext()->setContextProperty("_pmc_is_desktop", Settings().value("isDesktop",false));
 
-    view->setSource(QUrl(package->filePath("mainscript")));
+    view->setSource(QUrl(mainscriptPath));
 
-    if (view->rootObject() && urls.count() > 0) {
-        QTimer::singleShot(500, this, SLOT(playPlaylist()));
-    }
     resize(1366, 768);
 
     installEventFilter(this);
@@ -156,12 +150,12 @@ bool MainWindow::toggleFullScreen()
     return (windowState() & Qt::WindowFullScreen);
 }
 
-bool MainWindow::queryExit()
+void MainWindow::closeEvent(QCloseEvent *event)
 {
     Settings s;
-    windowState() & Qt::WindowFullScreen ? s.setValue("fullscreen", true) : s.setValue("fullscreen", false);
+    s.setValue("fullscreen", (windowState() & Qt::WindowFullScreen) != 0);
     s.sync();
-    return KMainWindow::queryExit();
+    KMainWindow::closeEvent(event);
 }
 
 void MainWindow::closeMediaCenter()
@@ -214,7 +208,68 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
     return false;
 }
 
-void MainWindow::playPlaylist()
+void MainWindow::addNewInstanceArgsPlaylist()
 {
-    view->rootObject()->metaObject()->invokeMethod(view->rootObject(), "play");
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    playlistModel->processCommandLineArgs(args);
+}
+
+bool MainWindow::loadThemeAndPopulateMainscriptAndImagesPath(QString& mainscriptPath, QString& imagesPath)
+{
+#ifdef NO_LINK_TO_PLASMA
+    qDebug() << "PLASMA_ADAPTER: Setting Oxygen Plasma theme and loading resources...";
+    typedef void (*MyPrototype)();
+    typedef QString (*QStringPrototype)();
+
+    QLibrary plasmaAdapterLib("plasmaadapter.so");
+    MyPrototype loadPlasmaTheme = (MyPrototype) plasmaAdapterLib.resolve("loadPlasmaTheme");
+    QStringPrototype getMainscriptPath = (QStringPrototype) plasmaAdapterLib.resolve("getMainscriptPath");
+    QStringPrototype getImagesPath = (QStringPrototype) plasmaAdapterLib.resolve("getImagesPath");
+
+    if (!plasmaAdapterLib.isLoaded()) {
+        return false;
+    }
+
+    if (loadPlasmaTheme) {
+        loadPlasmaTheme();
+    }
+
+    if (getMainscriptPath) {
+        mainscriptPath = getMainscriptPath();
+    }
+
+    if (getImagesPath) {
+        imagesPath = getImagesPath();
+    }
+
+    plasmaAdapterLib.unload();
+
+#else
+    qDebug() << "Setting Oxygen Plasma theme and loading resources...";
+    Plasma::Theme::defaultTheme()->setUseGlobalSettings(false);
+    Plasma::Theme::defaultTheme()->setThemeName("oxygen");
+
+    Plasma::PackageStructure::Ptr structure = Plasma::PackageStructure::load("Plasma/Generic");
+    Plasma::Package *package = new Plasma::Package(QString(), "org.kde.plasma.mediacenter", structure);
+
+    mainscriptPath = package->filePath("mainscript");
+
+    imagesPath = package->filePath("images");
+#endif
+    return true;
+}
+
+void MainWindow::raiseAndFocusPMC()
+{
+    raise();
+    KWindowSystem::forceActiveWindow(winId());
+}
+
+QSharedPointer<PmcRuntime> MainWindow::createPmcRuntime(QDeclarativeEngine* engine,
+                                         const QSharedPointer<PlaylistModel> &playlistModel)
+{
+    QHash< PmcRuntime::RuntimeObjectType, QSharedPointer< QObject > > runtimeObjects;
+    runtimeObjects.insert(PmcRuntime::PlaylistModel, playlistModel);
+
+    return QSharedPointer<PmcRuntime>(new PmcRuntime(runtimeObjects, engine, this));
 }
