@@ -26,7 +26,10 @@
 
 #include <QDeclarativeView>
 #include <QtCore/QTimer>
+#include <mediacenter/playlistmodel.h>
+#include "application.h"
 
+class PmcRuntime;
 class QKeyEvent;
 class QMouseEvent;
 
@@ -36,7 +39,7 @@ class MainWindow : public KMainWindow
     Q_PROPERTY(bool mousePointerAutoHide READ mousePointerAutoHide
                 WRITE setMousePointerAutoHide NOTIFY mousePointerAutoHideChanged)
 public:
-    explicit MainWindow(QWidget *parent = 0);
+    explicit MainWindow(Application *parent);
 
     bool mousePointerAutoHide() const;
     void setMousePointerAutoHide(bool value);
@@ -46,20 +49,23 @@ public Q_SLOTS:
     bool toggleFullScreen();
     void hideMousePointer();
     void showMousePointer();
-    void playPlaylist();
+    void addNewInstanceArgsPlaylist();
 
 Q_SIGNALS:
     void mousePointerAutoHideChanged();
 
 private Q_SLOTS:
     void enableMousePointerAutoHideIfNeeded();
+    void raiseAndFocusPMC();
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event);
-    virtual bool queryExit();
+    void closeEvent(QCloseEvent *event);
 
 private:
-    Plasma::PackageStructure::Ptr m_structure;
+    bool loadThemeAndPopulateMainscriptAndImagesPath(QString &mainscriptPath, QString &imagesPath);
+    QSharedPointer<PmcRuntime> createPmcRuntime(QDeclarativeEngine* engine, const QSharedPointer< PlaylistModel >& playlistModel);
+
     KDeclarative m_kdeclarative;
 
     bool m_mousePointerAutoHide;
@@ -67,6 +73,7 @@ private:
     QTimer m_mousePointerAutoHideTimer;
 
     QDeclarativeView *view;
+    QSharedPointer<PlaylistModel> playlistModel;
 };
 
 #endif // MAINWINDOW_H
